@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDIT_EDITORUTIL_H
-#define KPIMTEXTEDIT_EDITORUTIL_H
+#pragma once
 #include "kpimtextedit_export.h"
 
 #include <QTextCursor>
@@ -23,4 +22,3 @@ public:
 };
 }
 
-#endif // KPIMTEXTEDIT_EDITORUTIL_H
