@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -26,7 +26,7 @@ protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 private:
-    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
+    KPIMTextEdit::TextEditorCompleter *const mTextEditorCompleter;
     KSyntaxHighlighting::Repository mRepo;
 };
 }
