@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPIMTEXTEDIT_SELECTSPECIAL_CHARDIALOG_H
-#define KPIMTEXTEDIT_SELECTSPECIAL_CHARDIALOG_H
+#pragma once
 
 #include "kpimtextedit_export.h"
 
@@ -41,11 +40,10 @@ Q_SIGNALS:
     void charSelected(QChar);
 
 private:
-    SelectSpecialCharDialogPrivate *const d;
-    friend class SelectSpecialCharDialogPrivate;
     void readConfig();
     void writeConfig();
+    friend class SelectSpecialCharDialogPrivate;
+    std::unique_ptr<SelectSpecialCharDialogPrivate> const d;
 };
 }
 
-#endif // KPIMTEXTEDIT_SELECTSPECIAL_CHAR_H
